import QtQuick 2.0
import QtQuick.Controls 1.0
import QtQuick.Window 2.1
import DemoPlugin 1.0

ApplicationWindow {
    visible: true
    width: 800
    height: 1280
    // blsize is meant to be baseline (font) size in
    // rest of app.  We choose it here based on height of screen
    property int blsize : Screen.height > 1200 ? 40 : 20
    
    FontLoader { id: spaceFont; source: "space_age.ttf" }
    Rectangle {
        id: rootapp
        color: "#212126"
        Image{
            source:"images/background.jpeg"
            fillMode: Image.Tile
            anchors.fill: parent
        }
        opacity: 1.0
        anchors.fill: parent
    }

    // Implements back key navigation
    Keys.onReleased: {
        if (event.key === Qt.Key_Back) {
            if (stackView.depth > 1) {
                stackView.pop();
                event.accepted = true;
            } else { Qt.quit(); }
        }
    }

    toolBar: BorderImage {
        border.bottom: 8
        source: "images/toolbar.png"
        width: parent.width
        height: 100

        Rectangle {
            id: backButton
            width: opacity ? 60 : 0
            anchors.left: parent.left
            anchors.leftMargin: 20
            opacity: stackView.depth > 1 ? 1 : 0
            anchors.verticalCenter: parent.verticalCenter
            antialiasing: true
            height: 60
            radius: 4
            color: backmouse.pressed ? "#222" : "transparent"
            Behavior on opacity { NumberAnimation{} }
            Image {
                anchors.verticalCenter: parent.verticalCenter
                source: "images/navigation_previous_item.png"
            }
            MouseArea {
                id: backmouse
                anchors.fill: parent
                anchors.margins: -10
                onClicked: { rootapp.opacity = 1.0; stackView.pop(); }
            }
        }

        Text {
            id: titletext
            font.pixelSize: 52
            Behavior on x { NumberAnimation{ easing.type: Easing.OutCubic} }
            x: backButton.x + backButton.width + 20
            anchors.verticalCenter: parent.verticalCenter
            color: "white"
            text: "Star Tracks"
            font.family: spaceFont.name
        }
        // Text {
        //     font.pixelSize: 20
        //     x: backButton.x + backButton.width + 20
        //     color: "white"
        //     text: "(Opacity problems should be hidden now)"
        //     anchors.top: titletext.bottom
        // }
            
    }

    ListModel {
        id: pageModel
        ListElement {
            title: "Milky Way vs other galaxies"
            font.pixelSize: blsize
            page: "overview.qml"
            image: "images/overview/02-Mellinger.jpg"
        }
        ListElement {
            title: "Orbits"
            page: "orbitdemo.qml"
            image: "images/mw/2.jpg"
        }
        ListElement {
            title: "Zooming away!"
            page: "zoom.qml"
            image: "images/zoom/RS-pic5-final.jpg"
        }
        ListElement {
            title: "Star catcher"
            page: "starcatcher.qml"
            image: "images/mw/4.jpeg"
        }
    }

    StackView {
        id: stackView
        anchors.bottom: parent.bottom
        initialItem: Item {
            width: parent.width
            
            GridView {
                id: grid
                model: pageModel
                width: parent.width
                
                // width: parent.width
                // height: parent.height-100
                cellWidth: 0.5*parent.width
                cellHeight: 0.5*parent.height

                anchors.fill: parent
                delegate: Column {
                    Rectangle{
                        width: imageid.width * imageid.scale + 20
                        height: imageid.height * imageid.scale + 20
                        border.color: "#2C75FF"
                        border.width: 2
                        smooth: true
                        antialiasing: true
                        anchors.horizontalCenter: parent.horizontalCenter 
                        rotation: Math.random() * 11 - 6
                        Image {
                            id: imageid
                            width:grid.cellWidth-100
                            height:grid.cellHeight-100
                            source: image
                            fillMode: Image.PreserveAspectCrop
                            anchors.centerIn: parent
                            // anchors.horizontalCenter: parent.horizontalCenter 
                            // fillMode: Image.PreserveAspectFit
                            // scale: defaultSize / Math.max(sourceSize.width, sourceSize.height)
                            antialiasing: true
                        }
                        Text { 
                            text: title;
                            font.pixelSize: blsize
                            color: "white"
                            anchors.horizontalCenter: parent.horizontalCenter 
                            anchors.top: parent.bottom 
                            font.family: "Futura"
                        }
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                rootapp.opacity = 0.0
                                stackView.push(Qt.resolvedUrl(page))
                            }
                        }
                    }
                }
            }
        }
    }
}
