import QtQuick 2.0

// http://qt-project.org/doc/qt-5/qtquick-demos-photosurface-photosurface-qml.html

Rectangle {
    color: "black"

    ListModel {
        id: pixModel

        ListElement {
            imagePath: "01-Nightsky.jpg";
            explanatoryText: "Astronomy Picture of the Day, 14 May 2014

Long exposure of the night sky seen from Albion, Maine (USA). The wide band of light in the centre of the image is the Milky Way, our Galaxy. The thin stripe in the upper right part of the image is a shooting star."
            visible: true
        }
        ListElement {
            imagePath: "02-Mellinger.jpg";
            explanatoryText: "A view of the sky if we could look through the Earth. This all sky panorama is a combination of more than 3000 individual photographs taken from 2007-2009 showing the Milky Way dominating the night sky. The dark clouds are not in the Earth's atmosphere, but are due to dust clouds in interstellar space. The two bright spots in the lower right part of the image are the Magellanic clouds, two small nearby galaxies."
            visible: true
        }
        ListElement {
            imagePath: "03-The_Infrared_Milky_Way.jpg";
            explanatoryText: "The Milky Way seen in infrared light that is invisible for the human eye. Infrared light is less absorbed by dust clouds. Observing this light allows us to see deep into Galactic centre that is hidden from us otherwise. The positions, brightnesses and colours of half a billion stars were combined to make this picture.";
        }
        ListElement {
            imagePath: "04-MilkyWay-faceon.jpg";
            explanatoryText: "An artist's impression of how our Milky Way might look seen from above. The image is based on our best understanding of its structure. Because the Sun and the Earth are situated inside the Milky Way, we cannot see it from this perspective. The postion of the Sun and the Earth is marked in the lower part of the image. Their distance to the centre of the Galaxy is ~27,000 light years (8.3 kpc). For comparison, the distance between Earth and Sun is only 8 light minutes. Credit: NASA";
        }
        ListElement {
            imagePath: "04b-Gaia_star_density.jpg";
            explanatoryText: "The density of stars that we expect to see with Gaia, overlaid on an artist's impression of the Milky Way. Higher densities will be seen near the Sun (because a higher fraction of stars will be bright enough to be seen). There will also more stars seen near the plane of the Galaxy than away from it, because there are more stars there, and near the centre of the Galaxy, for the same reason.  Credit: X. Luri";
        }
        ListElement {
            imagePath: "05-Andromeda_Galaxy.jpg";
            explanatoryText: "Our next nearest substantial neighbour, the Andromeda galaxy. It is very similar to our Galaxy in terms of mass and size and is situated at a distance of about 2.5 million light years (~800 kpc). It is the most distant object easily seen with the unaided eye. The numerous dots in the image are almost exclusively stars of our own Galaxy and hence are in front of Andromeda. Their distances are generally well below 10 kpc. Image credit: Adam Evans"
        }
        ListElement {
            imagePath: "06-Hubble_ultra_deep_field.jpg"
            explanatoryText: "The Hubble Ultra Deep Field

This image was taken by the Hubble space telescope observing the same small patch on the sky for almost 12 days. The region was specifically chosen to contain very few stars. Only the few objects with a four spikes around them are stars of our own Galaxy. All the other objects are distant galaxies that contain billions of stars themselves. For some of these galaxies the light travelled almost as long as the age of the Universe to reach us. Credit: NASA, ESA"
        }
        ListElement {
            imagePath: "milkyway_layered_1.jpg"
            explanatoryText: "Artist's impression of the Milky Way, based on our best understanding of its structure (NASA/JPL-Caltech)."
        }
        ListElement {
            imagePath: "milkyway_layered_2.jpg"
            explanatoryText: "Our place in the Milky Way."
        }
        ListElement {
            imagePath: "milkyway_layered_3.jpg"
            explanatoryText: "The Sun is orbiting the centre of the Galaxy. The red arrow shows the direction it is moving, and the black path is the path it has taken."
        }
        ListElement {
            imagePath: "milkyway_layered_4.jpg"
            explanatoryText: "It takes about 200 million years for the Sun to orbit the Galaxy once, so it has only gone about a third of the way round since the dinosaurs died out."
        }
    }
            
    
    Component {
        id: pixDelegate
        Rectangle {
            id: photoFrame
            width: root.width
            height: root.height
            border.color: "black"
            border.width: 2
            smooth: true
            antialiasing: true
            color: "black"
            //x: 0.5*root.width - defaultSize
            //y: 0.5*root.height - defaultSize
            //rotation: Math.random() * 13 - 6
            Image {
                id: image
                anchors.centerIn: parent
                anchors.fill: parent
                fillMode: Image.PreserveAspectFit
                source: "images/overview/"+imagePath
                //scale: 1.0
                antialiasing: true
            }
            // PinchArea {
            //     anchors.fill: image
            //     pinch.target: photoFrame
            //     pinch.minimumRotation: -360
            //     pinch.maximumRotation: 360
            //     pinch.minimumScale: 0.1
            //     pinch.maximumScale: 10
            //     onPinchFinished: photoFrame.border.color = "black";
            // }
            Text {
                id: textbox
                z: 20
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.margins: 20
                font.pixelSize: blsize
                color: "black"
                wrapMode: Text.WordWrap
                text: explanatoryText
                
            }
            Rectangle {
                color: Qt.rgba(1,1,1,0.7)
                radius : 10
                border.color: "white"
                anchors.fill: textbox
                anchors.margins: -10
            }
        }
    }


    ListView {
        anchors.fill: parent
        model: pixModel
        delegate: pixDelegate
        orientation: Qt.Horizontal
        snapMode: ListView.SnapOneItem
    }

}
