#include <QtCore>
#include <QVector>
#include <QVector3D>
#include "orbit.h"
#include <iostream>
using namespace std;

Potential::Potential(qreal M, qreal q) : M(M), q(q) {}

QVector3D Potential::accel(const QVector3D &x) const {
  QVector3D m(x[0],x[1],x[2]/q);
  qreal m2 = m.lengthSquared();
  return -M*m/(1.0+m2);
}

Orbit::Orbit() : nstep(0) {
  ts = new qreal[maxnstep];
  xs = new QVector3D[maxnstep];
  vs = new QVector3D[maxnstep];
  xs[0] = QVector3D(1.0, 0.0, 0.0);
  vs[0] = QVector3D(0.1, 0.5, 0.0);
  leapfrog(0.05,maxnstep);
}
Orbit::~Orbit() {
  nstep = 0;
  delete[] vs;
  delete[] xs;
  delete[] ts;
}

void Orbit::setQ(qreal q) {
  m_q = q;
}
  
void Orbit::setMass(qreal m) {
  m_mass = m;
}


void Orbit::leapfrog(qreal dt, int nstep_) {
  Potential pot(m_mass,m_q);
  qreal t = 0.0;
  QVector3D x = xs[0];
  QVector3D v = vs[0];
  nstep = min(maxnstep,nstep_);
  //xs.clear(); vsn.clear();
  qreal xmax = 0.0, ymax = 0.0;
  for(int n=0;n<nstep;n++) {
    x += 0.5*dt*v;
    t += 0.5*dt;
    v += dt*pot.accel(x);
    x += 0.5*dt*v;
    t += 0.5*dt;
    ts[n] = t;
    xs[n] = x;
    vs[n] = v;
    if(fabs(x[0])>xmax) xmax = x[0];
    if(fabs(x[1])>ymax) ymax = x[1];
  }
}
