#ifndef ORBIT_H
#define ORBIT_H

#include <QtQuick/QQuickItem>
#include <QVector>
#include <QVector3D>
const int  maxnstep=100000;

class Potential {
 public:
  Potential();
  Potential(qreal M, qreal q);
  QVector3D accel(const QVector3D &x) const;
 private:
  qreal M, q;
};

class Orbit : public QObject {
  Q_OBJECT
  Q_PROPERTY(QVector3D x0 READ x0 WRITE setX0 NOTIFY x0Changed)
  Q_PROPERTY(QVector3D v0 READ x0 WRITE setV0 NOTIFY v0Changed)
  Q_PROPERTY(qreal q READ q WRITE setQ)
  Q_PROPERTY(qreal mass READ mass WRITE setMass)
  
 public:
  Orbit();
  ~Orbit();
  // getters
  QVector3D x0() const { return xs[0]; }
  QVector3D v0() const { return vs[0]; }
  qreal q() const { return m_q; }
  qreal mass() const { return m_mass; }

  // setters
  void setX0(const QVector3D &x0) {
    xs[0] = x0;
  }
  void setV0(const QVector3D &v0) {
    vs[0] = v0;
  }
  void setQ(qreal q);
  void setMass(qreal m);
  
  // orbit timeseries
  qreal *ts;
  QVector3D *xs;
  QVector3D *vs;
  int nstep;
  
 signals:
  void x0Changed();
  void v0Changed();
  
  // Calculate orbit
  public slots:
    void leapfrog(qreal dt, int nstep);

 private:
    // Potential parameters
    qreal m_q, m_mass;
};

#endif
