#ifndef ORBITCLOUD_H
#define ORBITCLOUD_H

#include <QtQuick/QQuickItem>
#include <QVector>
#include <QVector3D>

class OrbitCloud: public QObject{
  Q_OBJECT
  Q_PROPERTY(QVector3D x0 READ x0 WRITE setX0 NOTIFY x0Changed)
  Q_PROPERTY(QVector3D y0 READ y0 WRITE setY0 NOTIFY y0Changed)
  Q_PROPERTY(QVector3D z0 READ z0 WRITE setZ0 NOTIFY z0Changed)
  Q_PROPERTY(QVector3D vx0 READ vx0 WRITE setVx0 NOTIFY vx0Changed)
  Q_PROPERTY(QVector3D vy0 READ vy0 WRITE setVy0 NOTIFY vy0Changed)
  Q_PROPERTY(QVector3D vz0 READ vz0 WRITE setVz0 NOTIFY vz0Changed)
  Q_PROPERTY(qreal q READ q WRITE setQ)
  Q_PROPERTY(qreal mass READ mass WRITE setMass)
  
 public:
  OrbitCloud();
  // getters
  QVector3D x0() const { return xin; }
  QVector3D y0() const { return yin; }
  QVector3D z0() const { return zin; }
  QVector3D vx0() const { return vxin; }
  QVector3D vy0() const { return vyin; }
  QVector3D vz0() const { return vzin; }
  qreal q() const { return m_q; }
  qreal mass() const { return m_mass; }

  // setters
  void setX0(const QVector3D &x0) {
    xin=x0;
  }
  void setY0(const QVector3D &y0) {
    yin=y0;
  }
  void setZ0(const QVector3D &z0) {
    zin=z0;
  }
  void setVx0(const QVector3D &vx0) {
    vxin=vx0;
  }
  void setVy0(const QVector3D &vy0) {
    vyin=vy0;
  }
  void setVz0(const QVector3D &vz0) {
    vzin=vz0;
  }
  void setQ(qreal q);
  void setMass(qreal m);
  QVector<qreal> ts;
  QVector3D xin, yin, zin, vxin, vyin, vzin;
  QVector<QVector3D>xs,vs;
 signals:
  void x0Changed();
  void y0Changed();
  void z0Changed();
  void vx0Changed();
  void vy0Changed();
  void vz0Changed();
  public slots:
    void leapfrog(qreal dt, int nstep);

 private:
    // Potential parameters
    qreal m_q, m_mass;
};


#endif
