#ifndef ORBITCLOUDWIDGET_H
#define ORBITCLOUDWIDGET_H

#include <QtQuick/QQuickItem>
#include <QtGui/QOpenGLShaderProgram>
#include <QQmlListProperty>
#include "orbit.h"
#include "orbitcloud.h"

class OrbitCloudWidget : public QQuickItem {
    Q_OBJECT
    //Q_PROPERTY(qreal t READ t WRITE setT NOTIFY tChanged)
    Q_PROPERTY(qreal frac2Show READ frac2Show
               WRITE setFrac2Show NOTIFY frac2ShowChanged)
    Q_PROPERTY(QMatrix4x4 modelview READ modelview WRITE setModelview
               NOTIFY modelviewChanged)
    Q_PROPERTY(OrbitCloud* orbits READ orbits WRITE setOrbit
               NOTIFY orbitChanged)
    Q_PROPERTY(bool showAxes READ showAxes WRITE setShowAxes
               NOTIFY showAxesChanged)
    
public:
    OrbitCloudWidget(QQuickItem *parent=0);

    qreal frac2Show() const { return m_frac2show; }
    QMatrix4x4 modelview() const { return m_modelview; }
    OrbitCloud *orbits() const { return m_orbits; }
    bool showAxes() const { return m_showaxes; }
    void setFrac2Show(qreal frac2show);
    void setModelview(QMatrix4x4 modelview);
    void setOrbit(OrbitCloud *orbits);
    void setShowAxes(bool onoff);
    
 signals:
    void modelviewChanged();
    void frac2ShowChanged();
    void orbitChanged();
    void showAxesChanged();
    
public slots:
    void paint();
    void cleanup();
    void sync();

private slots:
    void handleWindowChanged(QQuickWindow *win);
private:
    QOpenGLShaderProgram *m_program;
    QMatrix4x4 m_modelview;
    QMatrix4x4 m_thread_modelview;
    bool m_showaxes;
    bool m_thread_showaxes;
    qreal m_frac2show;
    qreal m_thread_frac2show;
    int vertexAttr1;
    int matrixUniform1;
    int N;
    GLfloat *vertices;
    OrbitCloud *m_orbits;
    
};

#endif // ORBITCLOUDWIDGET_H
