#ifndef ORBITWIDGET_H
#define ORBITWIDGET_H

#include <QtQuick/QQuickItem>
#include <QtGui/QOpenGLShaderProgram>
#include <QQmlListProperty>
#include "orbit.h"

class OrbitWidget : public QQuickItem {
    Q_OBJECT
    //Q_PROPERTY(qreal t READ t WRITE setT NOTIFY tChanged)
    Q_PROPERTY(qreal frac2Show READ frac2Show
               WRITE setFrac2Show NOTIFY frac2ShowChanged)
    Q_PROPERTY(QMatrix4x4 modelview READ modelview WRITE setModelview
               NOTIFY modelviewChanged)
    Q_PROPERTY(Orbit* orbit READ orbit WRITE setOrbit
               NOTIFY orbitChanged)
    Q_PROPERTY(bool showAxes READ showAxes WRITE setShowAxes
               NOTIFY showAxesChanged)
    
public:
    OrbitWidget(QQuickItem *parent=0);
    ~OrbitWidget();

    qreal frac2Show() const { return m_frac2show; }
    QMatrix4x4 modelview() const { return m_modelview; }
    Orbit *orbit() const { return m_orbit; }
    bool showAxes() const { return m_showaxes; }
    void setFrac2Show(qreal frac2show);
    void setModelview(QMatrix4x4 modelview);
    void setOrbit(Orbit *orbit);
    void setShowAxes(bool onoff);
    
 signals:
    void modelviewChanged();
    void frac2ShowChanged();
    void orbitChanged();
    void showAxesChanged();
    
public slots:
    void paint();
    void cleanup();
    void sync();

private slots:
    void handleWindowChanged(QQuickWindow *win);
private:
    void plotTetrahedron(const QVector3D &x,
                         const QVector4D &color,
                         float dx);
    void plotEqPlane();
    QOpenGLShaderProgram *m_program;
    QMatrix4x4 m_modelview;
    QMatrix4x4 m_thread_modelview;
    bool m_showaxes;
    bool m_thread_showaxes;
    qreal m_frac2show;
    qreal m_thread_frac2show;
    int matrixUniform1;
    int N;
    GLfloat vertices[3*maxnstep];
    Orbit *m_orbit;
    qreal xmax;
};

#endif // ORBITWIDGET_H
