import QtQuick 2.1
import QtQuick.Controls 1.1
import QtQuick.Controls.Styles 1.1
import QtQuick.Layouts 1.1
import DemoPlugin 1.0

Rectangle {
    id : subroot
    opacity: 1.0
    color: "#00FFFFFF"
    property int nframes : 200
    property real q : 0.8
    property real m : 1.0
    OrbitCloud {
        id : myorbits
        mass : 1.0   // characteristic mass of potential
        q  : 0.8     // flattening of potential
        // true: 1.33568 0.517863
        x0 : Qt.vector3d(-0.227232,-0.162589, -0.194086) // ICs
        y0 : Qt.vector3d(0.143546,0.405695,0.541459) // ICs
        z0 : Qt.vector3d(0.00352842,0.197365, -0.0499254) // ICs
        vx0 : Qt.vector3d(0.357242,0.348548,0.359524) // ICs
        vy0 : Qt.vector3d(0.126388,0.114373,0.233569)
        vz0 : Qt.vector3d(0.103631,0.40659,-0.177168)
        Component.onCompleted: { // Make sure it's drawn!
            myorbits.leapfrog(0.01,nframes)
            myorbitwidget.orbits = myorbits
        }
    }   
 
    PinchArea {
        anchors.fill: parent
        onPinchUpdated: {
            // Rotate/zoom if pinched
            var m = myorbitwidget.modelview
            var f = pinch.previousScale/pinch.scale
            var dangle = (pinch.angle - pinch.previousAngle)*Math.PI/180
            var cosphi = Math.cos(dangle), sinphi = Math.sin(dangle)
            var mrotscale = Qt.matrix4x4( cosphi, -sinphi, 0,0,
                                          sinphi, cosphi, 0,0,
                                          0,            0, 1,0,
                                          0,            0, 0,f)
            myorbitwidget.modelview = mrotscale.times(m)
        }
        MouseArea {
            anchors.fill: parent
            hoverEnabled: false
            property int previousX: 0
            property int previousY: 0
            onPressed: {
                previousX = mouse.x
                previousY = mouse.y
            }
            onPositionChanged: {
                // Change orientation if dragged
                var bx = mouse.x - previousX
                var by = mouse.y - previousY
                previousX = mouse.x
                previousY = mouse.y
                var phix = by*0.01
                var phiy = bx*0.01
                var  m = myorbitwidget.modelview
                var cosphix = Math.cos(phix), sinphix = Math.sin(phix);
                var Rx = Qt.matrix4x4( 1,      0,      0, 0,
                                       0, cosphix,-sinphix, 0,
                                       0, sinphix, cosphix, 0,
                                       0,      0,      0, 1)
                var cosphiy = Math.cos(phiy), sinphiy = Math.sin(phiy);
                var Ry = Qt.matrix4x4( cosphiy, 0,  sinphiy, 0,
                                       0,       1,        0, 0,
                                       -sinphiy,0,  cosphiy, 0,
                                       0,       0,        0, 1)
                myorbitwidget.modelview = Rx.times(Ry.times(m))
            }

            // An 'OrbitWidget' projects an 'Orbit' onto
            // the *background*.  The implementation of
            // 'OrbitWidget' is in the c++ file plugin/orbitwidget.cpp.
            // The definition of what an 'Orbit' is in the c++ file
            // This particular OrbitWidget is referred to as
            // 'myorbitwidget'.  The 'modelview' property directly
            // controls the projection of 'myorbit' onto the screen.
            OrbitCloudWidget {
                id : myorbitwidget
                orbits : myorbits
                showAxes : false
                modelview : Qt.matrix4x4(1,0,0,0,
                                         0,1,0,0,
                                         0,0,1,0,
                                         0,0,0,1)
                // Animate the orbit by making the 'frac2Show'
                // member of the c++ OrbitWidget class run
                // continuously between 0 and 1.
                property bool animated : true
                SequentialAnimation on frac2Show {
                    id: animation
                    NumberAnimation {
                        from: 0.0;
                        to: 1.0;
                        duration: 500;
                        easing.type: Easing.InQuad
                    }
                    // loops: Animation.Infinite
                    running: true
                }
            }
        }
    }        
    // Now we set up the controls.
    // This should make sense after a few readings.
    Row {
        anchors.left: parent.left
        anchors.top: parent.top
        anchors.margins: 30
        spacing : 40  
        width:parent.width 
        Column{
            width:0.5*parent.width
            Slider {
                style: SliderStyle {
                    groove: Rectangle {
                        implicitWidth: 300
                        implicitHeight: 8
                        color: "gray"
                        radius: 8
                    }
                    handle: Rectangle {
                        anchors.centerIn: parent
                        color: control.pressed ? "white" : "lightgray"
                        border.color: "gray"
                        border.width: 2
                        width: 34
                        height: 34
                        radius: 12
                    }
                }
                minimumValue: 0
                maximumValue: 2
                value: m
                orientation: Qt.Horizontal
                updateValueWhileDragging: true
                onValueChanged: {
                    m = value
                    myorbits.mass = m
                    // myorbits.x0 = Qt.vector3d(x0,0,0)
                    // myorbits.v0 = Qt.vector3d(0,vy,vz)
                    myorbits.leapfrog(0.01,nframes)
                    myorbitwidget.orbits = myorbits
                }
            }
            Text { text: "Mass";
                   font.pixelSize: blsize; color: "white" }
        }
        Column{
            width:0.5*parent.width
            Slider {
                style: SliderStyle {
                    groove: Rectangle {
                        implicitWidth: 300
                        implicitHeight: 8
                        color: "gray"
                        radius: 8
                    }
                    handle: Rectangle {
                        anchors.centerIn: parent
                        color: control.pressed ? "white" : "lightgray"
                        border.color: "gray"
                        border.width: 2
                        width: 34
                        height: 34
                        radius: 12
                    }
                }
                minimumValue: 0
                maximumValue: 2
                value: q
                orientation: Qt.Horizontal
                updateValueWhileDragging: true
                onValueChanged: {
                    q = value
                    myorbits.q = q
                    // myorbit.x0 = Qt.vector3d(x0,0,0)
                    // myorbit.v0 = Qt.vector3d(0,vy,vz)
                    myorbits.leapfrog(0.01,nframes)
                    myorbitwidget.orbits = myorbits
                }
            }
            Text { text: "Flattening";
                   font.pixelSize: blsize; color: "white" }
        }
    }

    Rectangle {
        color: Qt.rgba(1, 1, 1, 0.7)
        radius: 10
        border.width: 1
        border.color: "white"
        anchors.fill: label
        anchors.margins: -10
    } 

    Text {
        id: label
        color: "black"
        wrapMode: Text.WordWrap
        text: "The night sky looked quite different when the dinosaurs roamed the earth.  Back then, the above three stars all used to be near the Sun. The green paths show the paths traced by each star since the dinosaurs died out. Can you adjust the size and shape of the galaxy until the stars coincide 60 million years ago? 
        How might we know that three stars came from the same place?"
        anchors.right: parent.right
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        anchors.margins: 20
        font.pixelSize:blsize;
    }
}
